@@ -2,7 +2,7 @@
  * @Author: BuddyCoder
  * @Date: 2021-08-24 14:50:48
  * @LastEditors: BuddyCoder
- * @LastEditTime: 2022-04-06 11:07:48
+ * @LastEditTime: 2022-04-09 14:02:55
  * @Description: 
  * @FilePath: /pgmacro_expand_demo/pgmacro/src/macros/crud_table_impl.rs
  * MIT
@@ -148,7 +148,13 @@
                   None => format!("{}",#table_name)
              };
              match suffix {
-                Some(t) => format!("{}_{}",temp_table_name,t),
+                Some(t) => {
+                    if t.eq(""){
+                        format!("{}",temp_table_name)
+                    }else{
+                        format!("{}_{}",temp_table_name,t)
+                    }     
+                },
                 None => format!("{}",temp_table_name)
             }
          }
